@@ -28,6 +28,8 @@ from eva.server.server import start_server  # noqa: E402
 from eva.udfs.udf_bootstrap_queries import init_builtin_udfs  # noqa: E402
 from eva.configuration.configuration_manager import \
     ConfigurationManager  # noqa: E402
+from eva.configuration.bootstrap_environment import \
+    bootstrap_environment  # noqa: E402
 from eva.utils.logging_manager import LoggingManager  # noqa: E402
 from eva.utils.logging_manager import LoggingLevel  # noqa: E402
 
@@ -36,7 +38,8 @@ def eva():
     """
         Start the eva system
     """
-
+    # Setup EVA environment in user home directory
+    bootstrap_environment()
     # Get the hostname and port information from the configuration file
     config = ConfigurationManager()
     hostname = config.get_value('server', 'host')
